@@ -1,5 +1,5 @@
-__version__ = "v0.8.1"
+__version__ = "v0.8.2"
 PREFAB_MAGIC_BYTES = b"_".join([b"PREFAB_CLASSES", __version__.encode()])
 
-from .dynamic import prefab, attribute
+from .dynamic import prefab, attribute, build_prefab
 from .sentinels import KW_ONLY
